# awk -f g2e.awk example-gpub/
BEGIN{
	gpubdir = ARGV[1]
	epubtdir = "template-epub/"
	epubodir = "out/"
	metadatafile = gpubdir "metadata.txt"

	# read metadata file fields
	while( getline < metadatafile ){
		key = $1
		sub(":","",key)
		value = $2
		for(i=3;i<=NF;i++) value = value " " $i

		meta[key] = value

		# set index file as an argument to be read
		if(key == "index" ){
			ARGV[1] = (gpubdir value) # overwrite argument 1
			# store index dirname:
			indexdirname = value
			sub(/[^/]+\.gmi$/,"",indexdirname)
		}
	}

	# read linked files from index and append as arguments
	while( getline < (gpubdir meta["index"]) ){
		if($1~"=>") ARGV[ARGC++] = gpubdir indexdirname $2
	}

	# setup epub
	system( "mkdir -p " epubodir "OEBPS" )
	system( "cp -ru " epubtdir "META-INF " epubodir )
	system( "cp -u " epubtdir "mimetype " epubodir )

	content = ""
	content = write_template( epubtdir "OEBPS/content-header.opf" )

	spinetoc = "  <spine toc=\"ncx\">\n"
}

# write the template into output, replacing {keys} with contents of meta["keys"]
function write_template( templatepath ){
	output = ""
	while( getline < templatepath ){
		if(match($0,/\{[^{}]+\}/)){ # has {key}
			key = substr($0,RSTART+1,RLENGTH-2)
			output = output substr($0, 1, RSTART-1) # before {key}
			output = output meta[key]
			output = output substr($0, RSTART+RLENGTH) "\n"
		}
		else{ # normal line
			output = output $0 "\n"
		}
	}
	return output
}

# index file links
ARGIND==1 && /^=>/{
	id = $2
	sub(/.gmi$/,"",id)
	content = content "    <item id=\""id"\" href=\""id".xhtml\" media-type=\"application/xhtml+xml\"/>\n"
	spinetoc = spinetoc "    <itemref idref=\""id"\" />\n"
}
# content files
ARGIND==2 && FNR==1{
	content = content "  </manifest>\n\n" spinetoc "  </spine>\n\n</package>"
	printf content > epubodir "OEBPS/content.opf"
}
ARGIND>1{
	print $0
}
END{
#	for(k in meta) print k, meta[k]
}


